<?php

namespace Drupal\content_entity_builder\Plugin\BaseFieldConfig;

use Drupal\Core\Form\FormStateInterface;
use Drupal\content_entity_builder\ConfigurableBaseFieldConfigBase;
use Drupal\content_entity_builder\ContentTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use \Drupal\Core\Entity\ContentEntityTypeInterface;

/**
 * EntityReferenceItemBaseFieldConfig.
 *
 * @BaseFieldConfig(
 *   id = "entity_reference_base_field_config",
 *   label = @Translation("Entity reference"),
 *   description = @Translation("An entity field containing an entity reference."),
 *   field_type = "entity_reference",
 *   category = @Translation("Reference")
 * )
 */
class EntityReferenceItemBaseFieldConfig extends ConfigurableBaseFieldConfigBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return array(
      'target_type' => '',
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
	$entity_types = \Drupal::entityTypeManager()->getDefinitions();
	$entity_type_options =array();
	foreach($entity_types as $key => $entitytype){
	  
	  if($entitytype instanceof ContentEntityTypeInterface){
	    $entity_type_options[$key] = $entitytype->getLabel();
	  }
	}
    $form['target_type'] = array(
      '#type' => 'select',
      '#title' => $this->t('Entity Type'),
	  '#options' => $entity_type_options,
      '#default_value' => $this->configuration['target_type'],
      '#required' => TRUE,	  
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
	$this->configuration['target_type'] = $form_state->getValue('target_type');
  }
  
  /**
   * {@inheritdoc}
   */
  public function buildBaseFieldDefinition() {
    $field_type = $this->getFieldType();
    $label = $this->getLabel(); 
    $weight = $this->getWeight();
    $default_value = $this->getDefaultValue();		
    $base_field_definition = BaseFieldDefinition::create($field_type)
	    ->setLabel(t($label))
        ->setSetting('target_type', $this->configuration['target_type'])
        ->setSetting('handler', 'default')
        ->setDisplayOptions('view', array(
          'label' => 'hidden',
          'type' => 'entity_reference_label',
          'weight' => 0,
        ))
        ->setDisplayOptions('form', array(
          'type' => 'entity_reference_autocomplete',
          'weight' => 5,
          'settings' => array(
            'match_operator' => 'CONTAINS',
            'size' => '60',
            'autocomplete_type' => 'tags',
            'placeholder' => '',
          ),
        ))
        ->setDisplayConfigurable('form', TRUE)
	    ->setDisplayConfigurable('view', TRUE);			

    return $base_field_definition;
  }
}
