<?php

namespace Drupal\content_entity_builder\Plugin\BaseFieldConfig;

use Drupal\Core\Form\FormStateInterface;
use Drupal\content_entity_builder\ConfigurableBaseFieldConfigBase;
use Drupal\content_entity_builder\ContentTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * ListIntegerItemBaseFieldConfig.
 *
 * @BaseFieldConfig(
 *   id = "list_integer_base_field_config",
 *   label = @Translation("List (integer)"),
 *   description = @Translation("This field stores integer values from a list of allowed 'value => label' pairs, i.e. 'Lifetime in days': 1 => 1 day, 7 => 1 week, 31 => 1 month."),
 *   field_type = "list_integer",
 *   category = @Translation("Number")
 * )
 */
class ListIntegerItemBaseFieldConfig extends ListItemBaseFieldConfigBase {
  
  /**
   * {@inheritdoc}
   */
  public function buildBaseFieldDefinition() {
    $field_type = $this->getFieldType();
    $label = $this->getLabel(); 
    $weight = $this->getWeight();
    $default_value = $this->getDefaultValue();	
    $allowed_values = $this->configuration['allowed_values'];	
    $base_field_definition = BaseFieldDefinition::create($field_type)
	    ->setLabel(t($label))
		//->setDefaultValue($default_value)
		->setSetting('allowed_values',  static::extractAllowedValues($allowed_values))
		->setDisplayOptions('view', array(
			'label' => 'above',
			'type' => 'list_default',
			'weight' => $weight,
		))
		->setDisplayOptions('form', array(
			'type' => 'options_select',
			'weight' => $weight,
		))		
        ->setDisplayConfigurable('form', TRUE)
	    ->setDisplayConfigurable('view', TRUE);			

    return $base_field_definition;
  }
}
