<?php

namespace Drupal\content_entity_builder\Plugin\BaseFieldConfig;

use Drupal\Core\Form\FormStateInterface;
use Drupal\content_entity_builder\ConfigurableBaseFieldConfigBase;
use Drupal\content_entity_builder\ContentTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * TelephoneItemBaseFieldConfig.
 *
 * @BaseFieldConfig(
 *   id = "telephone_base_field_config",
 *   label = @Translation("Telephone number"),
 *   description = @Translation("This field stores a telephone number in the database."),
 *   field_type = "telephone",
 *   dependency = "telephone", 
 *   category = @Translation("Number")
 * )
 */
class TelephoneItemBaseFieldConfig extends ConfigurableBaseFieldConfigBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
  }
  
  /**
   * {@inheritdoc}
   */
  public function buildBaseFieldDefinition() {
    $field_type = $this->getFieldType();
    $label = $this->getLabel(); 
    $weight = $this->getWeight();
    $default_value = $this->getDefaultValue();		
    $base_field_definition = BaseFieldDefinition::create($field_type)
	    ->setLabel(t($label))
		->setDefaultValue($default_value)
		->setDisplayOptions('view', array(
			'label' => 'above',
			'type' => 'basic_string',
			'weight' => $weight,
		))
		->setDisplayOptions('form', array(
			'type' => 'telephone_default',
			'weight' => $weight,
		))		
        ->setDisplayConfigurable('form', TRUE)
	    ->setDisplayConfigurable('view', TRUE);			

    return $base_field_definition;
  }
}
